==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/ScatterSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { ScatterSeriesDescription } from "./ScatterSeriesDescription";
/**
 * @hidden
 */
export let ScatterSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScatterSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ScatterSeriesDescriptionMetadata.a == null) {
                ScatterSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScatterSeriesDescriptionMetadata.c(ScatterSeriesDescriptionMetadata.a);
            }
            if (a.k(ScatterSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(ScatterSeriesDescriptionMetadata.a);
        }
        static c(a) {
            ScatterBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            ScatterSeriesDescriptionMetadata.b(a);
            a.ad("ScatterSeries", () => new ScatterSeriesDescription());
            a.ac("ScatterSeries", ScatterSeriesDescriptionMetadata.a);
        }
    }
    ScatterSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(ScatterSeriesDescriptionMetadata, 'ScatterSeriesDescriptionMetadata');
    ScatterSeriesDescriptionMetadata.a = null;
    return ScatterSeriesDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/ScatterSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { ScatterSeriesDescription } from "./ScatterSeriesDescription";
/**
 * @hidden
 */
export let ScatterSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScatterSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ScatterSeriesDescriptionMetadata.a == null) {
                ScatterSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScatterSeriesDescriptionMetadata.c(ScatterSeriesDescriptionMetadata.a);
            }
            if (a.k(ScatterSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(ScatterSeriesDescriptionMetadata.a);
        }
        static c(a) {
            ScatterBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            ScatterSeriesDescriptionMetadata.b(a);
            a.ae("ScatterSeries", () => new ScatterSeriesDescription());
            a.ad("ScatterSeries", ScatterSeriesDescriptionMetadata.a);
        }
    }
    ScatterSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(ScatterSeriesDescriptionMetadata, 'ScatterSeriesDescriptionMetadata');
    ScatterSeriesDescriptionMetadata.a = null;
    return ScatterSeriesDescriptionMetadata;
})();
